@@ -1,4 +1,12 @@
-use crate::rpu::{rpu_data_nlq::RpuDataNlq as RuRpuDataNlq, NUM_COMPONENTS};
+use std::ffi::CStr;
+
+use crate::rpu::{
+    NUM_COMPONENTS,
+    rpu_data_nlq::{DoviELType, RpuDataNlq as RuRpuDataNlq},
+};
+
+const FEL_CSTR: &CStr = c"FEL";
+const MEL_CSTR: &CStr = c"MEL";
 
 /// C struct for rpu_data_nlq()
 #[repr(C)]
@@ -12,6 +20,15 @@ pub struct RpuDataNlq {
     linear_deadzone_threshold: [u64; NUM_COMPONENTS],
 }
 
+impl DoviELType {
+    pub const fn as_cstr(&self) -> &'static CStr {
+        match self {
+            DoviELType::MEL => MEL_CSTR,
+            DoviELType::FEL => FEL_CSTR,
+        }
+    }
+}
+
 impl From<&RuRpuDataNlq> for RpuDataNlq {
     fn from(data: &RuRpuDataNlq) -> Self {
         Self {
